@@ -2,13 +2,10 @@ from copy import deepcopy
 from typing import Dict, List
 
 from instagrapi import config
-from instagrapi.exceptions import (
-    ClientError,
-    ClientLoginRequired,
-    ClientNotFoundError,
-    UserNotFound,
-)
-from instagrapi.extractors import extract_user_gql, extract_user_short, extract_user_v1
+from instagrapi.exceptions import (ClientError, ClientLoginRequired,
+                                   ClientNotFoundError, UserNotFound)
+from instagrapi.extractors import (extract_user_gql, extract_user_short,
+                                   extract_user_v1)
 from instagrapi.types import User, UserShort
 from instagrapi.utils import json_value
 
@@ -17,6 +14,7 @@ class UserMixin:
     """
     Helpers to manage user
     """
+
     _users_cache = {}  # user_pk -> User
     _userhorts_cache = {}  # user_pk -> UserShort
     _usernames_cache = {}  # username -> user_pk
@@ -209,9 +207,7 @@ class UserMixin:
         """
         user_id = int(user_id)
         # GraphQL haven't method to receive user by id
-        return self.user_info_by_username_gql(
-            self.username_from_user_id_gql(user_id)
-        )
+        return self.user_info_by_username_gql(self.username_from_user_id_gql(user_id))
 
     def user_info_v1(self, user_id: int) -> User:
         """
@@ -269,9 +265,11 @@ class UserMixin:
                 user = self.user_info_v1(user_id)
             self._users_cache[user_id] = user
             self._usernames_cache[user.username] = user.pk
-        return deepcopy(self._users_cache[user_id])  # return copy of cache (dict changes protection)
+        return deepcopy(
+            self._users_cache[user_id]
+        )  # return copy of cache (dict changes protection)
 
-    def user_following_gql(self, user_id: int, amount: int = 0) -> List[User]:
+    def user_following_gql(self, user_id: int, amount: int = 0) -> List[UserShort]:
         """
         Get user's followers information
 
@@ -284,7 +282,7 @@ class UserMixin:
 
         Returns
         -------
-        List[User]
+        List[UserShort]
             List of objects of User type
         """
         user_id = int(user_id)
@@ -294,7 +292,7 @@ class UserMixin:
             "id": user_id,
             "include_reel": True,
             "fetch_mutual": False,
-            "first": 24
+            "first": 24,
         }
         while True:
             if end_cursor:
@@ -304,12 +302,8 @@ class UserMixin:
             )
             if not data["user"] and not users:
                 raise UserNotFound(user_id=user_id, **data)
-            page_info = json_value(
-                data, "user", "edge_follow", "page_info", default={}
-            )
-            edges = json_value(
-                data, "user", "edge_follow", "edges", default=[]
-            )
+            page_info = json_value(data, "user", "edge_follow", "page_info", default={})
+            edges = json_value(data, "user", "edge_follow", "edges", default=[])
             for edge in edges:
                 users.append(extract_user_short(edge["node"]))
             end_cursor = page_info.get("end_cursor")
@@ -322,7 +316,7 @@ class UserMixin:
             users = users[:amount]
         return users
 
-    def user_following_v1(self, user_id: int, amount: int = 0) -> List[User]:
+    def user_following_v1(self, user_id: int, amount: int = 0) -> List[UserShort]:
         """
         Get user's followers information
 
@@ -335,13 +329,15 @@ class UserMixin:
 
         Returns
         -------
-        List[User]
+        List[UserShort]
             List of objects of User type
         """
         user_id = int(user_id)
         max_id = ""
         users = []
         while True:
+            if amount and len(users) >= amount:
+                break
             result = self.private_request(
                 f"friendships/{user_id}/following/",
                 params={
@@ -353,13 +349,15 @@ class UserMixin:
             for user in result["users"]:
                 users.append(extract_user_short(user))
             max_id = result.get("next_max_id")
-            if not max_id or (amount and len(users) >= amount):
+            if not max_id:
                 break
         if amount:
             users = users[:amount]
         return users
 
-    def user_following(self, user_id: int, use_cache: bool = True, amount: int = 0) -> Dict[int, User]:
+    def user_following(
+        self, user_id: int, use_cache: bool = True, amount: int = 0
+    ) -> Dict[int, UserShort]:
         """
         Get user's followers information
 
@@ -374,12 +372,13 @@ class UserMixin:
 
         Returns
         -------
-        Dict[int, User]
+        Dict[int, UserShort]
             Dict of user_id and User object
         """
         user_id = int(user_id)
         if not use_cache or user_id not in self._users_following:
             # Temporary: Instagram Required Login for GQL request
+            # You can inject sessionid from private to public session
             # try:
             #     users = self.user_following_gql(user_id, amount)
             # except Exception as e:
@@ -387,12 +386,13 @@ class UserMixin:
             #         self.logger.exception(e)
             #     users = self.user_following_v1(user_id, amount)
             users = self.user_following_v1(user_id, amount)
-            self._users_following[user_id] = {
-                user.pk: user for user in users
-            }
-        return self._users_following[user_id]
+            self._users_following[user_id] = {user.pk: user for user in users}
+        following = self._users_following[user_id]
+        if amount and len(following) > amount:
+            following = dict(list(following.items())[:amount])
+        return following
 
-    def user_followers_v1(self, user_id: int, amount: int = 0) -> List[User]:
+    def user_followers_v1(self, user_id: int, amount: int = 0) -> List[UserShort]:
         """
         Get user's followers information
 
@@ -405,13 +405,15 @@ class UserMixin:
 
         Returns
         -------
-        List[User]
+        List[UserShort]
             List of objects of User type
         """
         user_id = int(user_id)
         max_id = ""
         users = []
         while True:
+            if amount and len(users) >= amount:
+                break
             result = self.private_request(
                 f"friendships/{user_id}/followers/",
                 params={"max_id": max_id, "rank_token": self.rank_token},
@@ -419,11 +421,15 @@ class UserMixin:
             for user in result["users"]:
                 users.append(extract_user_short(user))
             max_id = result.get("next_max_id")
-            if not max_id or (amount and len(users) >= amount):
+            if not max_id:
                 break
+        if amount:
+            users = users[:amount]
         return users
 
-    def user_followers(self, user_id: int, use_cache: bool = True, amount: int = 0) -> Dict[int, User]:
+    def user_followers(
+        self, user_id: int, use_cache: bool = True, amount: int = 0
+    ) -> Dict[int, UserShort]:
         """
         Get user's followers
 
@@ -438,16 +444,17 @@ class UserMixin:
 
         Returns
         -------
-        Dict[int, User]
+        Dict[int, UserShort]
             Dict of user_id and User object
         """
         user_id = int(user_id)
         if not use_cache or user_id not in self._users_followers:
             users = self.user_followers_v1(user_id, amount)
-            self._users_followers[user_id] = {
-                user.pk: user for user in users
-            }
-        return self._users_followers[user_id]
+            self._users_followers[user_id] = {user.pk: user for user in users}
+        followers = self._users_followers[user_id]
+        if amount and len(followers) > amount:
+            followers = dict(list(followers.items())[:amount])
+        return followers
 
     def user_follow(self, user_id: int) -> bool:
         """
